# Manage a nginx vhost that reverse proxies to a Jenkins instance.
class tails::jenkins::reverse_proxy (
  $public_hostname = 'jenkins.tails.boum.org',
  $upstream_address = 'http://jenkins.lizard:8080/',
  ) {

  ### Sanity checks

  if $::osfamily != 'Debian' {
    fail('The tails::jenkins::reverse_proxy class only supports Debian.')
  }
  validate_string($public_hostname)
  validate_string($upstream_address)

  ### Resources

  nginx::vhostsd { $public_hostname:
    content  => template('tails/jenkins/nginx/reverse_proxy.erb'),
    require => [
      Package[nginx],
      Nginx::Authd['jenkins'],
      File['/etc/nginx/include.d/site_ssl.conf'],
    ];
  }

  nginx::authd { 'jenkins':
    source  => "puppet:///modules/site_jenkins/nginx/${::fqdn}/auth.d/htpasswd.jenkins",
  }

}
