class tails::jenkins::slave (
  $artifacts_root_dir,
  $master_url,
) {

  ### Sanity checks

  if $::osfamily != 'Debian' {
    fail('The tails::jenkins::slave class only supports Debian.')
  }
  
  validate_string($artifacts_root_dir)
  validate_string($master_url)

  ### Resources

  apt::preferences_snippet { ['jenkins-slave']:
      pin      => 'release o=Debian,n=jessie',
      priority => 991,
  }

  package { 'jenkins-slave':
    ensure  => present,
    require => Apt::Preferences_snippet['jenkins-slave'],
  }

  file_line { 'master_url':
    path    => '/etc/default/jenkins-slave',
    match   => '#?JENKINS_URL=(?:".*")?',
    line    => "JENKINS_URL='${master_url}'",
    require => Package['jenkins-slave'],
  }

  service { 'jenkins-slave':
    ensure    => running,
    hasstatus => false,
    pattern   => '/usr/bin/daemon --name=jenkins-slave',
    require   => File_line['master_url'],
  }

  # Make ARTIFACTS_ROOT_DIR available in /etc/jenkins/environment,
  # and manage the corresponding directory.

  file { '/etc/jenkins':
    ensure => directory,
    mode   => '0755',
  }

  file { '/etc/jenkins/environment':
    ensure => present,
    mode   => '0644',
  }

  file_line { 'ARTIFACTS_ROOT_DIR':
    path    => '/etc/jenkins/environment',
    match   => '#?ARTIFACTS_ROOT_DIR=(?:".*")?',
    line    => "ARTIFACTS_ROOT_DIR='${artifacts_root_dir}'",
    require => File['/etc/jenkins/environment'],
  }

  file { $artifacts_root_dir:
    ensure => directory,
    mode   => '0755',
  }

  file { '/var/lib/jenkins':
    ensure => directory,
    owner  => jenkins,
    group  => jenkins,
    mode   => '0755',
    require => Package['jenkins-slave'],
  }

  # SSH keys

  sshkeys::set_client_key_pair { 'jenkins@jenkins-slave':
    keyname => 'jenkins@jenkins-slave',
    user    => 'jenkins',
    home    => '/var/lib/jenkins',
  }

}
