class tails::reprepro::nginx (
  $hostname = undefined,
  $port     = 80,
  $basedir  = undefined,
  $managed  = true
){
  if $hostname == undefined {
    fail('Missing hostname for tails::reprepro::nginx class')
  }
  if $basedir == undefined {
    fail('Missing basedir for tails::reprepro::nginx class')
  }

  if $managed {
    class { '::nginx':
      access_log => 'noip',
      error_log  => 'none'
    }
  }

  nginx::vhostsd { 'deb.tails.boum.org':
      content => template('tails/reprepro/nginx/site.erb'),
      require => Package[nginx];
  }

  package { 'acl': ensure => installed }

  $acls = "${common::moduledir::module_dir_path}/tails/reprepro-webdirs.acl"
  file { $acls:
    content => "group::r-X\ndefault:group::r-X\nother::r-X\ndefault:other::r-X\n",
    owner   => root,
    group   => root,
    mode    => '0600',
  }
  exec {
    'set-acl-on-reprepro-web-dirs':
      command     => "setfacl -R -M $acls $basedir/dists $basedir/pool",
      require     => [
                      File[$acls, "$basedir/dists", "$basedir/pool"],
                      Package[acl]
                     ],
      subscribe   => File[$acls],
      refreshonly => true;
  }

}
